@@ -8,6 +8,14 @@ import pandas as pd
 from random import choice
 from string import digits
 import tempfile
+import pkgutil
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    # Try backported to PY<37 `importlib_resources`.
+    import importlib_resources as pkg_resources
+
+from . import style as style_dir
 
 if sys.version_info[0] == 2:  # the tkinter library changed it's name from Python 2 to 3.
     import Tkinter
@@ -67,7 +75,7 @@ class TaskWrapper():
         # info = subprocess.STARTUPINFO()
         # info.dwFlags = subprocess.STARTUPINFO()
         # info.wShowWindow = SW_MINIMIZE
-        p = subprocess.Popen(['python', filepath], cwd=self.cwd) #, startupinfo=info)
+        p = subprocess.Popen(['python3', filepath], cwd=self.cwd) #, startupinfo=info)
         # stdout, stderr = p.communicate()
         return p
     
@@ -231,18 +239,23 @@ def test_edit(save_location, h):
 def edit(save_location, haystack):
     main(save_location, haystack, editing=True)
 
-def main(save_location, haystack=r"C:\Users\Toto\Documents\AdAstraIndustries\aai_engine\img\cv.png", editing=False):
+def main(save_location, needle=r"C:\Users\Toto\Documents\AdAstraIndustries\aai_engine\img\cv.png", editing=False):
     temp_screenshot = tempfile.NamedTemporaryFile(suffix='.png')
     temp_screenshot_path = temp_screenshot.name
-    # take_screenshot(temp_screenshot_path)
-    take_screenshot()
+    if os.name == "posix":
+        temp_screenshot_path = temp_screenshot_path.split(".")[0] + "_000.png"
+    print("TEMP PATH: ", temp_screenshot_path)
+    take_screenshot(temp_screenshot_path)
+    # take_screenshot()
     # TODO: make title bar black
     # aai_window = AAIWindow()
     # root = aai_window.root
     
     root = tkinter.Tk()
     style = ttk.Style(root)
-    root.wm_iconbitmap(icon_path)
+    # iconfile = pkg_resources.read_binary(style_dir, 'icon.ico')
+    # iconfile = pkgutil.get_data(__name__, "style/icon.ico")
+    # root.wm_iconbitmap(icon_path)
     root.wm_colormapwindows()
     
     root.tk.call('source', theme_path)
@@ -250,10 +263,10 @@ def main(save_location, haystack=r"C:\Users\Toto\Documents\AdAstraIndustries\aai
 
     if editing:
         print(" - EDIT MODE - ")
-        app = ScreenShotTaker(root, save_location, haystack=haystack, editing=True) # When editing from extension
+        app = ScreenShotTaker(root, save_location, needle=needle, haystack=temp_screenshot_path, editing=True) # When editing from extension
     else:
         print(" - CREATE MODE - ")
-        app = ScreenShotTaker(root, save_location, editing=False)
+        app = ScreenShotTaker(root, save_location, haystack=temp_screenshot_path, editing=False)
 
     root.mainloop()
 
